@@ -141,7 +141,6 @@ test_that("gt_order_loci reorders and regenerates backingfiles", {
 
   # read back in
   reorder_test_gt <- gen_tibble(path_bed, quiet = TRUE)
-  expect_true(is.integer(show_loci(reorder_test_gt)$chr_int))
   expect_true(is.integer(show_loci(reorder_test_gt)$position))
 
   # loci are out of order
@@ -257,13 +256,14 @@ test_that("gt_order_loci catches unsorted and duplicated positions", {
     allele_alt = c("T", "C", NA, "C", "G", "A")
   )
   path <- tempfile()
-  test_gt <- gen_tibble(
+  expect_warning(test_gt <- gen_tibble(
     x = test_genotypes,
     loci = test_loci,
     indiv_meta = test_indiv_meta,
     quiet = TRUE,
+    allow_duplicates = TRUE,
     backingfile = path
-  )
+  ), "You have allowed duplicated loci")
   new_order <- c(1, 2, 3, 6, 4, 5)
   # manually reorder so loci are ordered, but have duplicates
   show_loci(test_gt) <- show_loci(test_gt)[new_order, ]
@@ -421,17 +421,14 @@ test_that("gt_update_backingfile catches unsorted and duplicated genetic_dist",
     quiet = TRUE,
     backingfile = tempfile()
   )
+  expect_equal(show_loci(test_gt)$genetic_dist, c(0.1, 0.3, 0.2, 0.4, 0.5, 0.6))
+
   test_gt <- gt_update_backingfile(test_gt,
     rm_unsorted_dist = TRUE,
     quiet = TRUE
   )
-
-  rds <- readRDS(gt_get_file_names(test_gt)[1])
-  backingfile <- attr(test_gt$genotypes, "bigsnp")
+  # after updating backingfile, genetic_dist should all be zero
   expect_equal(show_loci(test_gt)$genetic_dist, c(0, 0, 0, 0, 0, 0))
-  expect_equal(backingfile$map$genetic.dist, c(0, 0, 0, 0, 0, 0))
-  expect_equal(rds$map$genetic.dist, c(0, 0, 0, 0, 0, 0))
-
 
   # Test duplicated dist
   test_loci <- data.frame(
@@ -442,6 +439,7 @@ test_that("gt_update_backingfile catches unsorted and duplicated genetic_dist",
     allele_ref = c("A", "T", "C", "G", "C", "T"),
     allele_alt = c("T", "C", NA, "C", "G", "A")
   )
+
   test_gt <- gen_tibble(
     x = test_genotypes,
     loci = test_loci,
@@ -449,16 +447,14 @@ test_that("gt_update_backingfile catches unsorted and duplicated genetic_dist",
     quiet = TRUE,
     backingfile = tempfile()
   )
+  expect_equal(show_loci(test_gt)$genetic_dist, c(0, 0, 0.2, 0.4, 0.5, 0.6))
+
   test_gt <- gt_update_backingfile(test_gt,
     rm_unsorted_dist = TRUE,
     quiet = TRUE
   )
-
-  rds <- readRDS(gt_get_file_names(test_gt)[1])
-  backingfile <- attr(test_gt$genotypes, "bigsnp")
+  # after updating backingfile, genetic_dist should all be zero
   expect_equal(show_loci(test_gt)$genetic_dist, c(0, 0, 0, 0, 0, 0))
-  expect_equal(backingfile$map$genetic.dist, c(0, 0, 0, 0, 0, 0))
-  expect_equal(rds$map$genetic.dist, c(0, 0, 0, 0, 0, 0))
 })
 
 
@@ -562,13 +558,14 @@ test_that("is_loci_table_ordered catches unsorted and duplicated positions", {
     allele_ref = c("A", "T", "C", "G", "C", "T"),
     allele_alt = c("T", "C", NA, "C", "G", "A")
   )
-  test_gt <- gen_tibble(
+  expect_warning(test_gt <- gen_tibble(
     x = test_genotypes,
     loci = test_loci,
     indiv_meta = test_indiv_meta,
     quiet = TRUE,
+    allow_duplicates = TRUE,
     backingfile = tempfile()
-  )
+  ), "You have allowed duplicated loci")
   expect_false(is_loci_table_ordered(test_gt))
   expect_error(
     is_loci_table_ordered(test_gt, error_on_false = TRUE),
@@ -655,7 +652,7 @@ test_that("check updated positions/distances are inherited by the merged gt", {
 })
 
 
-test_that("gt_order_loci works respects chr_int, when original chromosome is character", { # nolint
+test_that("cast_chromosome_to_int transforms correctly from character", {
   test_indiv_meta <- data.frame(
     id = c("a", "b", "c"),
     population = c("pop1", "pop1", "pop2")
@@ -680,16 +677,20 @@ test_that("gt_order_loci works respects chr_int, when original chromosome is cha
     quiet = TRUE,
     backingfile = tempfile()
   )
-  # check chr_int makes sense
-  expect_equal(show_loci(test_gt)$chr_int, c(2, 13, 8, 1, 2, 3))
+  expect_equal(
+    cast_chromosome_to_int(show_loci(test_gt)$chromosome),
+    c(2, 13, 8, 1, 2, 3)
+  )
   # use gt_order_loci to reorder
   test_gt <- gt_order_loci(test_gt, use_current_table = FALSE, quiet = TRUE)
-  expect_equal(show_loci(test_gt)$chr_int, c(1, 2, 2, 3, 8, 13))
-  expect_equal(show_loci(test_gt)$chromosome, c("1", "2", "2", "3", "8", "13"))
+  expect_equal(
+    cast_chromosome_to_int(show_loci(test_gt)$chromosome),
+    c(1, 2, 2, 3, 8, 13)
+  )
 })
 
 
-test_that("gt_order_loci works respects chr_int, when original chromosome is factor", { # nolint
+test_that("cast_chromosome_to_int transforms correctly from factor", {
   test_indiv_meta <- data.frame(
     id = c("a", "b", "c"),
     population = c("pop1", "pop1", "pop2")
@@ -715,10 +716,16 @@ test_that("gt_order_loci works respects chr_int, when original chromosome is fac
     backingfile = tempfile()
   )
   # check chr_int makes sense
-  expect_equal(show_loci(test_gt)$chr_int, c(2, 13, 8, 1, 2, 3))
+  expect_equal(
+    cast_chromosome_to_int(show_loci(test_gt)$chromosome),
+    c(2, 13, 8, 1, 2, 3)
+  )
   # use gt_order_loci to reorder
   test_gt <- gt_order_loci(test_gt, use_current_table = FALSE, quiet = TRUE)
-  expect_equal(show_loci(test_gt)$chr_int, c(1, 2, 2, 3, 8, 13))
+  expect_equal(
+    cast_chromosome_to_int(show_loci(test_gt)$chromosome),
+    c(1, 2, 2, 3, 8, 13)
+  )
   expect_equal(
     as.character(show_loci(test_gt)$chromosome),
     as.character(c(1, 2, 2, 3, 8, 13))
